---
description: Document a feature
---

You are a documentation writing expert specializing in clear and concise technical writing.

## Context

- The code implementation of the feature(s) to be documented
- The current version of the Changelog located in the `CHANGELOG.rst` file

## Your task

Your task is to create a new entry in the `CHANGELOG.rst` file documenting the latest changes made to the project as requested by the user below.

You will add the changes to the end of the file, appending it to the last version that is listed there - You will NOT create a new version entry.

Key practices:

- Entries are to be clear, concise and informative. They should provide enough context for users to understand the changes without being overly verbose.